@@ -82,14 +82,7 @@ where
     /// # Ok::<(), io::Error>(())
     /// ```
     pub fn read_file_definition(&mut self) -> io::Result<FileDefinition> {
-        let magic = read_magic(&mut self.inner)?;
-
-        if magic != MAGIC_NUMBER {
-            return Err(io::Error::new(
-                io::ErrorKind::InvalidData,
-                "invalid CRAM header",
-            ));
-        }
+        read_magic_number(&mut self.inner)?;
 
         let format = read_format(&mut self.inner)?;
         let file_id = read_file_id(&mut self.inner)?;
@@ -102,8 +95,8 @@ where
     /// The position of the stream is expected to be at the CRAM header container, i.e., directly
     /// after the file definition.
     ///
-    /// This returns the raw SAM header as a [`std::string::String`]. It can subsequently be parsed
-    /// as a [`noodles_sam::Header`].
+    /// This returns the raw SAM header as a [`String`]. It can subsequently be parsed as a
+    /// [`noodles_sam::Header`].
     ///
     /// # Examples
     ///
@@ -210,13 +203,21 @@ where
     }
 }
 
-fn read_magic<R>(reader: &mut R) -> io::Result<[u8; 4]>
+fn read_magic_number<R>(reader: &mut R) -> io::Result<()>
 where
     R: Read,
 {
     let mut buf = [0; 4];
     reader.read_exact(&mut buf)?;
-    Ok(buf)
+
+    if buf == MAGIC_NUMBER {
+        Ok(())
+    } else {
+        Err(io::Error::new(
+            io::ErrorKind::InvalidData,
+            "invalid CRAM header",
+        ))
+    }
 }
 
 fn read_format<R>(reader: &mut R) -> io::Result<Version>
@@ -263,54 +264,32 @@ fn read_file_header_block(block: &Block) -> io::Result<String> {
 
 #[cfg(test)]
 mod tests {
+    use std::convert::TryFrom;
+
     use crate::{container::block::ContentType, num::Itf8};
 
     use super::*;
 
-    fn build_file_definition() -> Vec<u8> {
-        let mut data = MAGIC_NUMBER.to_vec();
-
-        let format = [0x03, 0x00];
-        data.extend_from_slice(&format);
-
-        let file_id = [
-            0x00, 0x68, 0xac, 0xf3, 0x06, 0x4d, 0xaa, 0x1e, 0x29, 0xa4, 0xa0, 0x8c, 0x56, 0xee,
-            0x91, 0x9b, 0x91, 0x04, 0x21, 0x1f,
-        ];
-        data.extend_from_slice(&file_id);
-
-        data
-    }
-
     #[test]
-    fn test_read_file_definition() -> io::Result<()> {
-        let data = build_file_definition();
-        let mut reader = Reader::new(&data[..]);
+    fn test_read_file_definition() -> Result<(), Box<dyn std::error::Error>> {
+        let data = [
+            0x43, 0x52, 0x41, 0x4d, // magic number = b"CRAM"
+            0x03, 0x00, // format version = (3, 0)
+            0x00, 0x68, 0xac, 0xf3, 0x06, 0x4d, 0xaa, 0x1e, 0x29, 0xa4, 0xa0, 0x8c, 0x56, 0xee,
+            0x91, 0x9b, 0x91, 0x04, 0x21, 0x1f, // file ID
+        ];
 
+        let mut reader = Reader::new(&data[..]);
         let actual = reader.read_file_definition()?;
-        let expected = FileDefinition::new(
-            Version::new(3, 0),
-            [
-                0x00, 0x68, 0xac, 0xf3, 0x06, 0x4d, 0xaa, 0x1e, 0x29, 0xa4, 0xa0, 0x8c, 0x56, 0xee,
-                0x91, 0x9b, 0x91, 0x04, 0x21, 0x1f,
-            ],
-        );
+
+        let file_id = <[u8; 20]>::try_from(&data[6..])?;
+        let expected = FileDefinition::new(Version::new(3, 0), file_id);
 
         assert_eq!(actual, expected);
 
         Ok(())
     }
 
-    #[test]
-    fn test_read_file_definition_with_invalid_magic_number() {
-        let data = b"BAM\x01";
-        let mut reader = Reader::new(&data[..]);
-        assert!(matches!(
-            reader.read_file_definition(),
-            Err(ref e) if e.kind() == io::ErrorKind::InvalidData,
-        ));
-    }
-
     #[test]
     fn test_read_file_header_block() -> io::Result<()> {
         let expected = "noodles";
@@ -345,4 +324,28 @@ mod tests {
             Err(ref e) if e.kind() == io::ErrorKind::InvalidData
         ));
     }
+
+    #[test]
+    fn test_read_magic_number() {
+        let data = b"CRAM";
+        let mut reader = &data[..];
+        assert!(read_magic_number(&mut reader).is_ok());
+    }
+
+    #[test]
+    fn test_read_magic_number_with_invalid_input() {
+        let data = [];
+        let mut reader = &data[..];
+        assert!(matches!(
+            read_magic_number(&mut reader),
+            Err(ref e) if e.kind() == io::ErrorKind::UnexpectedEof,
+        ));
+
+        let data = b"BAM\x01";
+        let mut reader = &data[..];
+        assert!(matches!(
+            read_magic_number(&mut reader),
+            Err(ref e) if e.kind() == io::ErrorKind::InvalidData,
+        ));
+    }
 }
